@@ -52,7 +52,8 @@ typedef enum
 typedef enum
 {
     SRC_SPEECH_TEXT_ECHO_CHAR,
-    SRC_SPEECH_TEXT_ECHO_WORD
+    SRC_SPEECH_TEXT_ECHO_WORD,
+    SRC_SPEECH_TEXT_ECHO_NONE
 }SRCSpeechTextEchoType;
 
 typedef enum
@@ -88,6 +89,7 @@ typedef enum
 
 typedef enum
 {
+    SRC_SPEECH_PRIORITY_LOW,
     SRC_SPEECH_PRIORITY_IDLE,
     SRC_SPEECH_PRIORITY_MESSAGE,
     SRC_SPEECH_PRIORITY_SYSTEM,
@@ -130,5 +132,19 @@ SRCSpeechModifiersEchoType	src_speech_get_modifiers_echo_type ();
 SRCSpeechCursorsEchoType	src_speech_get_cursors_echo_type   ();
 
 /*FIXME end */
+gboolean src_speech_set_idle (gchar *ido);
+#ifdef SRS_NO_MARKERS_SUPPORTED
+gboolean src_speech_add_created_voice (gchar *name, gboolean has_callback);
+#else
+gboolean src_speech_add_created_voice (gchar *name);
+#endif
+
+typedef struct
+{
+    gchar *name;
+    gchar **voices;
+}SRSDriver;
+SRSDriver*	srs_driver_new ();
+gboolean src_speech_process_drivers (GPtrArray *drivers);
 
 #endif /* _SRSPC_H_ */
